<p align="center">
  <a href="https://expressjs.com/" target="_blank">
    <img src="https://expressjs.com/images/express-facebook-share.png" width="400">
  </a>
</p>

<p align="center">
  <img src="https://img.shields.io/badge/node-%2020.11.1-026e00.svg" alt="Nodejs Badge">
  <img src="https://img.shields.io/badge/yarn-%201.22.19-2188b6.svg" alt="yarn Badge">
</p>

# Services API

## Table of Contents

- [Features](#features)
- [Tech Specs](#tech-specs)
- [Development](#development)

  - [System Requirements](#system-requirements)
  - [Setup](#setup)
  - [Install](#install)
  - [Run](#run)
  - [Manage Database](#manage-database)
  - [Manage Services](#manage-services)
  - [Preview Docs](#preview-docs)
  - [Info](#info)
  - [Testing (e2e)](#testing-e2e)

- [Local environment](#local-environment)

### Features

- Authentication

### Tech Specs

- Http Server: [Express](https://expressjs.com/)
- Request Validation: [Celebrate](https://github.com/arb/celebrate#readme)
- ORM: [Typeorm](https://typeorm.io/)
- Database: [PostgreSQL](https://www.postgresql.org/docs/14/index.html)
- Mailing:
  - dev & testing: [MailHog](https://github.com/mailhog/MailHog)
  - qa & staging: [Mailtrap](https://mailtrap.io/)
  - production: _your_choice_
- Queues: [Bull](https://github.com/OptimalBits/bull#readme).
- Caching: [Redis](https://redis.io/).
- Error tracking: [Sentry](https://sentry.io/welcome/).
- Logging: [Winston](https://github.com/winstonjs/winston).
- API Docs: [Open API 3.0.3](https://swagger.io/specification/).
- Language: [Typescript](https://www.typescriptlang.org/).
- Containers: [Docker](https://docs.docker.com/engine/) and [Docker compose](https://docs.docker.com/compose/).

### Development

#### System Requirements

- [git](https://git-scm.com/downloads)
- [nodejs and yarn](#setup)
- [docker desktop](https://docs.docker.com/engine/install/#desktop)
- [docker compose](https://docs.docker.com/compose/install/#install-compose)

<details>
      <summary>VSCode extensions (recommended)</summary>

- [Prettier](https://marketplace.visualstudio.com/items?itemName=esbenp.prettier-vscode)
- [Eslint](https://marketplace.visualstudio.com/items?itemName=dbaeumer.vscode-eslint)
- [Editorconfig](https://marketplace.visualstudio.com/items?itemName=EditorConfig.EditorConfig)
- [Cucumber](https://marketplace.visualstudio.com/items?itemName=alexkrechik.cucumberautocomplete)
- [Open API (Swagger) Editor](https://marketplace.visualstudio.com/items?itemName=42Crunch.vscode-openapi)
- [Redocly OpenAPI](https://marketplace.visualstudio.com/items?itemName=Redocly.openapi-vs-code)
- [Conventional commits](https://marketplace.visualstudio.com/items?itemName=vivaxy.vscode-conventional-commits)

> The recommended extensions suggestions will appear when the project is open with vscode.
> For other code editors, search their equivalent extensions

</details>

#### Setup

- Nodejs and yarn

  <details>
  <summary>With asdf version manager (recommended)</summary>

  - mac and zsh

  ```
    .scripts/install-asdf-mac-zsh.sh
  ```

  - mac and bash

  ```
    .scripts/install-asdf-mac-bash.sh
  ```

  </details>
  <details>
  <summary>From source</summary>

  - [nodejs](https://nodejs.org/download/release/v20.11.1/)
  - [yarn](https://github.com/yarnpkg/yarn/releases/tag/v1.22.19)

  </details>

- Add environment variables

  ```
  cp .env-example .env
  ```

- Add the following records to `/etc/hosts` file

  ```
    127.0.0.1       host.docker.internal
    127.0.0.1       api.server.com
    127.0.0.1       db.server.com
    127.0.0.1       mail.server.com
  ```

#### Install

- Install dependencies

  ```
  yarn install
  ```

#### Run

- Start services

  ```
  make services.up
  ```

- Database migrate and seeding

  ```
  make services.db.seed
  ```

- Start server

  ```
  yarn start
  ```

#### Manage Database

- Migrations

  ```
  yarn migration:run
  ```

  ```
  yarn migration:revert
  ```

  ```
  yarn migration:generate
  ```

  ```
  yarn migration:create
  ```

- Seed
  ```
  yarn seed:dev
  ```

#### Manage Services

- Start services

  ```
  make services.up
  ```

- Stop services

  ```
  make services.down
  ```

- Stop services && remove volume data

  ```
  make services.destroy
  ```

#### Preview Docs

- Preview backoffice docs

  ```
  yarn docs:preview:backoffice
  ```

#### Info

- API: `http://api.server.com/api/v1`

- API Doc: `http://api.server.com/docs/v1`

- Mail Server: `http://mail.server.com`

- DB Admin: `http://db.server.com`

#### Testing (e2e)

- All services must be running and the database must have seeding data

  ```
  yarn e2e
  ```

### Local environment

- For replicate all services (api include), check this [guide](/LOCAL_ENVIRONMENT.md).
