import { Request, Response } from 'express'
import { SignInUseCase } from '../../../libs/application/use-cases/auth/sign-in-use-case'
import { SignOutUseCase } from '../../../libs/application/use-cases/auth/sign-out-use-case'
import { ForgotPasswordUseCase } from '@/libs/application/use-cases/auth/forgot-password-use-case'
import { ResetPasswordUseCase } from '@/libs/application/use-cases/auth/reset-password-use-case'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { container } from '../di/container'

const signInUseCase = container.get(SignInUseCase)
const signOutUseCase = container.get(SignOutUseCase)
const forgotPasswordUseCase = container.get(ForgotPasswordUseCase)
const resetPasswordUseCase = container.get(ResetPasswordUseCase)

export class AuthController {
  static async getMyProfile(req: Request, res: Response) {
    return res.json(req.user)
  }

  static async signIn(req: Request, res: Response) {
    const tokens = await signInUseCase.run(req.body, RequestContext.fromPrimitives(req))

    return res.json({ ...tokens })
  }

  static async signOut(req: Request, res: Response) {
    await signOutUseCase.run(RequestContext.fromPrimitives(req))

    return res.json({ message: 'Sesion finalizada con éxito.' })
  }

  static async forgotPassword(req: Request, res: Response) {
    await forgotPasswordUseCase.run(req.body, RequestContext.fromPrimitives(req))
    return res.json({
      message: 'Un enlace de restablecimiento de contraseña fue enviado a su correo electrónico.',
    })
  }

  static async resetPassword(req: Request, res: Response) {
    await resetPasswordUseCase.run(req.body, RequestContext.fromPrimitives(req))
    return res.json({
      message: 'Su contraseña se restableció correctamente.',
    })
  }
}
