import { Request, Response } from 'express'

import { CreateDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/create.use-case'
import { UpdateDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/update.use-case'
import { DeleteDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/delete.use-case'
import { ShowDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/show.use-case'
import { ListDefaultFieldsUseCase } from '@/libs/application/use-cases/default-field/list.use-case'
import { container } from '../di/container'

const createDefaultFieldUseCase = container.get(CreateDefaultFieldUseCase)
const updateDefaultFieldUseCase = container.get(UpdateDefaultFieldUseCase)
const deleteDefaultFieldUseCase = container.get(DeleteDefaultFieldUseCase)
const showDefaultFieldUseCase = container.get(ShowDefaultFieldUseCase)
const listDefaultFieldsUseCase = container.get(ListDefaultFieldsUseCase)

export class DefaultFieldController {
  static async create(req: Request, res: Response) {
    const response = await createDefaultFieldUseCase.run(req.body)

    return res.status(201).json(response)
  }

  static async update(req: Request, res: Response) {
    const { id } = req.params
    const response = await updateDefaultFieldUseCase.run(id, req.body)
    return res.json(response)
  }

  static async delete(req: Request, res: Response) {
    const { id } = req.params
    await deleteDefaultFieldUseCase.run(id)
    return res.sendStatus(204)
  }

  static async show(req: Request, res: Response) {
    const { id } = req.params
    const response = await showDefaultFieldUseCase.run(id)
    return res.json(response)
  }

  static async list(req: Request, res: Response) {
    const response = await listDefaultFieldsUseCase.run()
    return res.json(response)
  }
}
