import { Request, Response } from 'express'
import { UpdateFormTemplateUseCase } from '@/libs/application/use-cases/form-template/update.use-case'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { ShowFormTemplateUseCase } from '@/libs/application/use-cases/form-template/show.use-case'
import { container } from '../di/container'

const updateFormTemplateUseCase = container.get(UpdateFormTemplateUseCase)
const showFormTemplateUseCase = container.get(ShowFormTemplateUseCase)

export class FormTemplateController {
  static async update(req: Request, res: Response) {
    const response = await updateFormTemplateUseCase.run(
      req.body,
      RequestContext.fromPrimitives(req)
    )

    return res.json(response)
  }

  static async show(req: Request, res: Response) {
    const response = await showFormTemplateUseCase.run(RequestContext.fromPrimitives(req))

    return res.json(response)
  }
}
