import 'reflect-metadata'

import { ContainerBuilder } from 'diod'
import { UserRepository } from '@/libs/domain/repositories/tenant/user.repository'
import { TypeOrmUserRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-user-repository'
import { MailerService } from '@/libs/domain/services/mailer.service'
import { NodeMailerService } from '@/libs/infrastructure/services/node-mailer.service'
import { TypeOrmRoleRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-role-repository'
import { RoleRepository } from '@/libs/domain/repositories/tenant/role.repository'
import { PermissionRepository } from '@/libs/domain/repositories/tenant/permission.repository'
import { TypeOrmPermissionRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-permission.repository'

import { TenantRepository } from '@/libs/domain/repositories/master/tenant.repository'
import { TypeOrmTenantRepository } from '@/libs/infrastructure/persistance/repositories/master/typeorm-tenant.repository'
import { ConnectionRepository } from '@/libs/domain/repositories/master/connection.repository'
import { TypeOrmConnectionRepository } from '@/libs/infrastructure/persistance/repositories/master/typeorm-connection.repository'
import { DefaultFieldRepository } from '@/libs/domain/repositories/master/default-field.repository'
import { TypeOrmDefaultFieldRepository } from '@/libs/infrastructure/persistance/repositories/master/typeorm-default-field.repository'
import { SuperAdminRepository } from '@/libs/domain/repositories/master/super-admin.repository'
import { TypeOrmSuperAdminRepository } from '@/libs/infrastructure/persistance/repositories/master/typeorm-super-admin.repository'
import { TenantCategoryRepository } from '@/libs/domain/repositories/master/tenant-category.repsitory'
import { TypeOrmTenantCategoryRepository } from '@/libs/infrastructure/persistance/repositories/master/typeorm-tenant-category.repository'
import { CustomerRepository } from '@/libs/domain/repositories/tenant/customer.repository'
import { TypeOrmCustomerRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-customer.repository'
import { DriverRepository } from '@/libs/domain/repositories/tenant/driver.repository'
import { TypeOrmDriverRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-driver.repository'
import { EmployeeRepository } from '@/libs/domain/repositories/tenant/employee.repository'
import { TypeOrmEmployeeRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-employee.repository'
import { InvoiceRepository } from '@/libs/domain/repositories/tenant/invoice.repository'
import { TypeOrmInvoiceRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-invoice.repository'
import { OrderQuoteRepository } from '@/libs/domain/repositories/tenant/order-quote.repository'
import { TypeOrmOrderQuoteRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-order-quote.repository'
import { OrderStatusHistoryRepository } from '@/libs/domain/repositories/tenant/order-status-history.repository'
import { TypeOrmOrderStatusHistoryRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-order-status-history.repository'
import { OrderRepository } from '@/libs/domain/repositories/tenant/order.repository'
import { TypeOrmOrderRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-order.repository'
import { ShippingRepository } from '@/libs/domain/repositories/tenant/shipping.repository'
import { TypeOrmShippingRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-shipping-repository'
import { ShippingReceiverRepository } from '@/libs/domain/repositories/tenant/shipping-receiver.repository'
import { TypeOrmShippingReceiverRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-shipping-receiver.repository'
import { ShippingStatusHistoryRepository } from '@/libs/domain/repositories/tenant/shipping-status-history.repository'
import { TypeOrmShippingStatusHistoryRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-shipping-status-history.repository'
import { TransportCompanyRepository } from '@/libs/domain/repositories/tenant/transport-company.repository'
import { TypeOrmTransportCompanyRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-transport-company.repository'
import { TransportPaymentRepository } from '@/libs/domain/repositories/tenant/transport-payment.repository'
import { TypeOrmTransportPaymentRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-transport-payment.repository'
import { GetTenantUseCase } from '@/libs/application/use-cases/tenant/get.use-case'
import { DevSeeder } from '@/libs/infrastructure/persistance/seeders/dev.seeder'
import { ProdSeeder } from '@/libs/infrastructure/persistance/seeders/prod.seeder'
import { ValidateUserEmailUseCase } from '@/libs/application/use-cases/user/validate-email.use-case'
import { ValidateUserRutUseCase } from '@/libs/application/use-cases/user/validate-rut.use-case'
import { GetMyProfileUseCase } from '@/libs/application/use-cases/user/get-my-profile.use-case'
import { ValidateIdExistsUseCase } from '@/libs/application/use-cases/shared/validate-id-exists.use-case'
import { FormRepository } from '@/libs/domain/repositories/tenant/form.repository'
import { TypeOrmFormRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-form.repository'
import { TypeOrmFormTemplateRepository } from '@/libs/infrastructure/persistance/repositories/tenants/typeorm-form-template.repository'
import { FormTemplateRepository } from '@/libs/domain/repositories/tenant/form-template.repository'

import { SignOutUseCase } from '@/libs/application/use-cases/auth/sign-out-use-case'
import { SignInUseCase } from '@/libs/application/use-cases/auth/sign-in-use-case'
import { ForgotPasswordUseCase } from '@/libs/application/use-cases/auth/forgot-password-use-case'
import { ResetPasswordUseCase } from '@/libs/application/use-cases/auth/reset-password-use-case'
import { CreateCustomerUseCase } from '@/libs/application/use-cases/customer/create.use-case'
import { ShowCustomerUseCase } from '@/libs/application/use-cases/customer/show.use-case'
import { UpdateCustomerUseCase } from '@/libs/application/use-cases/customer/update.use-case'
import { DeleteCustomerUseCase } from '@/libs/application/use-cases/customer/delete.use-case'
import { ListCustomersUseCase } from '@/libs/application/use-cases/customer/list.use-case'
import { ValidateTransportCompanyRutUseCase } from '@/libs/application/use-cases/transport-company/validate-rut-use-case'
import { ValidateTransportCompanyEmailUseCase } from '@/libs/application/use-cases/transport-company/validate-email.use-case'
import { CreateTransportCompanyUseCase } from '@/libs/application/use-cases/transport-company/create.use-case'
import { UpdateTransportCompanyUseCase } from '@/libs/application/use-cases/transport-company/update.use-case'
import { ShowTransportCompanyUseCase } from '@/libs/application/use-cases/transport-company/show.use-case'
import { ListTransportCompaniesUseCase } from '@/libs/application/use-cases/transport-company/list.use-case'
import { DeleteTransportCompanyUseCase } from '@/libs/application/use-cases/transport-company/delete.use-case'
import { CreateDriverUseCase } from '@/libs/application/use-cases/driver/create.use-case'
import { UpdateDriverUseCase } from '@/libs/application/use-cases/driver/update.use-case'
import { DeleteDriverUseCase } from '@/libs/application/use-cases/driver/delete.use-case'
import { ShowDriverUseCase } from '@/libs/application/use-cases/driver/show.use-case'
import { ListDriversUseCase } from '@/libs/application/use-cases/driver/list.use-case'
import { UpdateFormTemplateUseCase } from '@/libs/application/use-cases/form-template/update.use-case'
import { ShowFormTemplateUseCase } from '@/libs/application/use-cases/form-template/show.use-case'
import { ListOrdersUseCase } from '@/libs/application/use-cases/order/list.use-case'
import { ShowOrderUseCase } from '@/libs/application/use-cases/order/show.use-case'
import { CreateOrderUseCase } from '@/libs/application/use-cases/order/create.use-case'

import { CreateDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/create.use-case'
import { DeleteDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/delete.use-case'
import { ListDefaultFieldsUseCase } from '@/libs/application/use-cases/default-field/list.use-case'
import { ShowDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/show.use-case'
import { UpdateDefaultFieldUseCase } from '@/libs/application/use-cases/default-field/update.use-case'

import { AdminGetMyProfileUseCase } from '@/libs/application/use-cases/admin-auth/get-my-profile.use-case'
import { AdminSignInUseCase } from '@/libs/application/use-cases/admin-auth/sign-in-use-case'
import { AdminSignOutUseCase } from '@/libs/application/use-cases/admin-auth/sign-out-use-case'

export const builder = new ContainerBuilder()

// services
builder.register(MailerService).use(NodeMailerService)

// master repositories
builder.register(ConnectionRepository).use(TypeOrmConnectionRepository)
builder.register(DefaultFieldRepository).use(TypeOrmDefaultFieldRepository)
builder.register(SuperAdminRepository).use(TypeOrmSuperAdminRepository)
builder.register(TenantCategoryRepository).use(TypeOrmTenantCategoryRepository)
builder.register(TenantRepository).use(TypeOrmTenantRepository)

// tenant repositories
builder.register(CustomerRepository).use(TypeOrmCustomerRepository)
builder.register(DriverRepository).use(TypeOrmDriverRepository)
builder.register(EmployeeRepository).use(TypeOrmEmployeeRepository)
builder.register(InvoiceRepository).use(TypeOrmInvoiceRepository)
builder.register(OrderQuoteRepository).use(TypeOrmOrderQuoteRepository)
builder.register(OrderStatusHistoryRepository).use(TypeOrmOrderStatusHistoryRepository)
builder.register(OrderRepository).use(TypeOrmOrderRepository)
builder.register(PermissionRepository).use(TypeOrmPermissionRepository)
builder.register(RoleRepository).use(TypeOrmRoleRepository)
builder.register(ShippingReceiverRepository).use(TypeOrmShippingReceiverRepository)
builder.register(ShippingStatusHistoryRepository).use(TypeOrmShippingStatusHistoryRepository)
builder.register(ShippingRepository).use(TypeOrmShippingRepository)
builder.register(TransportCompanyRepository).use(TypeOrmTransportCompanyRepository)
builder.register(TransportPaymentRepository).use(TypeOrmTransportPaymentRepository)
builder.register(UserRepository).use(TypeOrmUserRepository)
builder.register(FormRepository).use(TypeOrmFormRepository)
builder.register(FormTemplateRepository).use(TypeOrmFormTemplateRepository)

// seeders
builder.registerAndUse(DevSeeder)
builder.registerAndUse(ProdSeeder)

// use cases -----------------------------------

// shared
builder.registerAndUse(ValidateIdExistsUseCase)

// tenant
builder.registerAndUse(GetTenantUseCase)

// auth
builder.registerAndUse(SignInUseCase)
builder.registerAndUse(SignOutUseCase)
builder.registerAndUse(ForgotPasswordUseCase)
builder.registerAndUse(ResetPasswordUseCase)
builder.registerAndUse(GetMyProfileUseCase)
builder.registerAndUse(ValidateUserEmailUseCase)
builder.registerAndUse(ValidateUserRutUseCase)

// customers
builder.registerAndUse(CreateCustomerUseCase)
builder.registerAndUse(ShowCustomerUseCase)
builder.registerAndUse(UpdateCustomerUseCase)
builder.registerAndUse(DeleteCustomerUseCase)
builder.registerAndUse(ListCustomersUseCase)

// transport company
builder.registerAndUse(ValidateTransportCompanyRutUseCase)
builder.registerAndUse(ValidateTransportCompanyEmailUseCase)
builder.registerAndUse(CreateTransportCompanyUseCase)
builder.registerAndUse(UpdateTransportCompanyUseCase)
builder.registerAndUse(ShowTransportCompanyUseCase)
builder.registerAndUse(ListTransportCompaniesUseCase)
builder.registerAndUse(DeleteTransportCompanyUseCase)

// driver
builder.registerAndUse(CreateDriverUseCase)
builder.registerAndUse(UpdateDriverUseCase)
builder.registerAndUse(DeleteDriverUseCase)
builder.registerAndUse(ShowDriverUseCase)
builder.registerAndUse(ListDriversUseCase)

// form template
builder.registerAndUse(ShowFormTemplateUseCase)
builder.registerAndUse(UpdateFormTemplateUseCase)

// order
builder.registerAndUse(CreateOrderUseCase)
builder.registerAndUse(ShowOrderUseCase)
builder.registerAndUse(ListOrdersUseCase)

// default field
builder.registerAndUse(CreateDefaultFieldUseCase)
builder.registerAndUse(UpdateDefaultFieldUseCase)
builder.registerAndUse(DeleteDefaultFieldUseCase)
builder.registerAndUse(ShowDefaultFieldUseCase)
builder.registerAndUse(ListDefaultFieldsUseCase)

// admin auth
builder.registerAndUse(AdminGetMyProfileUseCase)
builder.registerAndUse(AdminSignInUseCase)
builder.registerAndUse(AdminSignOutUseCase)

export const container = builder.build()
