import { ErrorRequestHandler } from 'express'
import {
  BadRequestException,
  ForbiddenException,
  NotFoundException,
  UnauthorizedException,
} from '../../../libs/domain/errors'

export const error400Handler: ErrorRequestHandler = (err, _req, res, next) => {
  if (err instanceof BadRequestException) {
    return res.status(400).json({
      message: err.message,
    })
  }
  if (err instanceof UnauthorizedException) {
    return res.status(401).json({
      message: 'Unauthorized',
    })
  }
  if (err instanceof ForbiddenException) {
    return res.status(403).json({
      message: 'Forbidden action',
    })
  }

  if (err instanceof NotFoundException) {
    return res.status(404).json(err.message)
  }

  return next(err)
}
