import { NextFunction, Request, Response } from 'express'
import { GetTenantUseCase } from '@/libs/application/use-cases/tenant/get.use-case'
import { BadRequestException } from '@/libs/domain/errors'
import { ParametersValidationSchema } from '../validation-schemas/parameters.validation-schema'
import { container } from '../di/container'

const getTenantUseCase = container.get(GetTenantUseCase)

export const tenantMiddleware = [
  ParametersValidationSchema.tenantSubdomain,
  async (req: Request, res: Response, next: NextFunction) => {
    try {
      const tenantSubdomain = req.header('x-tenantsubdomain')

      const tenant = await getTenantUseCase.run({ subdomain: tenantSubdomain })

      if (!tenant?.id) {
        throw new BadRequestException('El inquilino no existe')
      }

      req.tenant = tenant

      return next()
    } catch (error) {
      return next(error)
    }
  },
]
