import { NextFunction, Request, Response } from 'express'
import _get from 'lodash/get'
import { container } from '../di/container'
import { ValidateUserEmailUseCase } from '@/libs/application/use-cases/user/validate-email.use-case'
import { RequestContext } from '@/libs/domain/contexts/request.context'

const validateUserEmailUseCase = container.get(ValidateUserEmailUseCase)

export const validateUserEmailMiddleware =
  (path = 'email') =>
  async (req: Request, res: Response, next: NextFunction) => {
    try {
      const email = _get(req.body, path)

      await validateUserEmailUseCase.run(email, RequestContext.fromPrimitives(req))

      return next()
    } catch (error) {
      return next(error)
    }
  }
