import { NextFunction, Request, Response } from 'express'
import _get from 'lodash/get'
import { ValidateUserRutUseCase } from '@/libs/application/use-cases/user/validate-rut.use-case'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { container } from '../di/container'

const validateUserRutUseCase = container.get(ValidateUserRutUseCase)

export const validateUserRutMiddleware =
  (path = 'rut') =>
  async (req: Request, res: Response, next: NextFunction) => {
    try {
      const rut = _get(req.body, path)

      await validateUserRutUseCase.run(rut, RequestContext.fromPrimitives(req))

      return next()
    } catch (error) {
      return next(error)
    }
  }
