import Router from 'express-promise-router'
import { authMiddleware } from '@/core/api/middlewares/auth.middleware'
import { Role } from '@/libs/infrastructure/persistance/seeders/dev.seeder'
import { OrderController } from '../controllers/order.controller'
import { OrderValidationSchema } from '../validation-schemas/order.validation-schema'
import { ParametersValidationSchema } from '@/core/api/validation-schemas/parameters.validation-schema'
import { validateIdExistsMiddleware } from '@/core/api/middlewares/validate-id-exists.middleware'

export const orderRouter = Router()
  .post('/', authMiddleware([Role.customer]), OrderValidationSchema.create, OrderController.create)
  .use('/:id', validateIdExistsMiddleware('order'))
  .get('/:id', authMiddleware(), OrderController.show)
  .get(
    '/',
    authMiddleware([Role.adminEmployee, Role.vendorEmployee, Role.customer]),
    ParametersValidationSchema.offsetCriteria,
    OrderController.list
  )
