import { FilterOperator } from '@/libs/domain/criteria/filters'
import { Joi, Segments, celebrate } from 'celebrate'

const filterOperators = Object.values(FilterOperator)

const filterSchema = Joi.array().items(
  Joi.object({
    field: Joi.string().required(),
    operator: Joi.string()
      .valid(...filterOperators)
      .required(),
    value: Joi.when('operator', {
      not: Joi.string().valid(FilterOperator.IS_NOT_NULL, FilterOperator.IS_NULL),
      then: Joi.alternatives()
        .try(
          Joi.string(),
          Joi.number(),
          Joi.boolean(),
          Joi.array().items(Joi.alternatives().try(Joi.string(), Joi.number(), Joi.boolean()))
        )
        .required(),
    }),
  }).options({
    allowUnknown: true,
  })
)

export class ParametersValidationSchema {
  static offsetCriteria = celebrate({
    [Segments.QUERY]: Joi.object({
      page: Joi.number().min(1),
      pageSize: Joi.number().min(1),
      filters: filterSchema,
      orderBy: Joi.string(),
      orderType: Joi.string().valid('asc', 'desc'),
    }).options({ allowUnknown: true }),
  })

  static cursorCriteria = celebrate({
    [Segments.QUERY]: Joi.object({
      cursor: Joi.string(),
      pageSize: Joi.number().min(1),
      filters: filterSchema,
    }).options({ allowUnknown: true }),
  })

  static id = celebrate({
    [Segments.PARAMS]: Joi.object({
      id: Joi.string().uuid({ version: 'uuidv4' }).required(),
    }).options({ allowUnknown: true }),
  })

  static tenantSubdomain = celebrate({
    [Segments.HEADERS]: Joi.object({
      'x-tenantsubdomain': Joi.string().required(),
    }).options({ allowUnknown: true }),
  })
}
