import { expect } from 'chai'
import { Given, When } from '@cucumber/cucumber'

import { CustomWorld } from '@/e2e/custom-world'
import { MailHelper } from '@/e2e/helpers/mail-helper'
import { testAdminEmployee } from '@/libs/infrastructure/persistance/seeders/dev.seeder'

Given('I request to forgot password instructions', async function (this: CustomWorld) {
  const response = await this.requestApi
    .post('/auth/forgot-password')
    .set('x-tenantsubdomain', this.tenantSubdomain)
    .send({
      email: testAdminEmployee.email,
    })
  expect(response.status).to.be.equal(200)
})

Given('I have a reset token and new password', async function (this: CustomWorld) {
  const resetToken = await MailHelper.getResetTokenFromEmail(testAdminEmployee.email!)
  this.body = {
    newPassword: '123456',
    token: resetToken,
  }
})

When('I request to reset password', async function (this: CustomWorld) {
  this.response = await this.requestApi
    .post('/auth/reset-password')
    .set('x-tenantsubdomain', this.tenantSubdomain)
    .send(this.body)
})
