import { CustomWorld } from '@/e2e/custom-world'
import { TenantRepository } from '@/libs/domain/repositories/master/tenant.repository'
import { DevSeeder } from '@/libs/infrastructure/persistance/seeders/dev.seeder'
import { Before } from '@cucumber/cucumber'

import { mailHogApi } from '../helpers/mail-helper'
import { appDataSource } from '@/libs/infrastructure/persistance/app-data-source'
import { expect } from 'chai'
import { container } from '@/core/api/di/container'

const tenantRepository = container.get(TenantRepository)
const devSeeder = container.get(DevSeeder)

Before(async function (this: CustomWorld) {
  // clear all email start
  await mailHogApi.deleteAll()
  // clear all email end

  // reset database start

  await appDataSource.dropDatabase()
  const schemas = await appDataSource.query(
    `SELECT schema_name FROM information_schema.schemata WHERE schema_name NOT LIKE 'pg_%' AND schema_name NOT IN ('information_schema','public');`
  )
  for (const schema of schemas) {
    await appDataSource.query(`DROP SCHEMA IF EXISTS "${schema.schema_name}" CASCADE;`)
  }
  await appDataSource.runMigrations()
  await devSeeder.run()
  // reset database end

  // get tenant id start
  if (!this.tenantId) {
    const tenant = await tenantRepository.findOne({
      subdomain: this.tenantSubdomain,
    })

    expect(tenant).to.have.property('id')

    this.tenantId = tenant?.id
  }
  // get tenant id end
})
