import { Injectable } from '@/core/api/di/decorators'
import { TokenEntity } from '@/libs/domain/entities/tenant/token.entity'
import { BadRequestException } from '@/libs/domain/errors'
import { EncryptHelper } from '@/libs/domain/helpers/encrypt.helper'
import { TokenHelper } from '@/libs/domain/helpers/token.helper'
import { SuperAdminRepository } from '@/libs/domain/repositories/master/super-admin.repository'

@Injectable()
export class AdminSignInUseCase {
  constructor(private readonly superAdminRepository: SuperAdminRepository) {}
  async run(payload: { email: string; password: string }): Promise<TokenEntity> {
    const superAdmin = await this.superAdminRepository.findOne({
      email: payload.email,
    })

    if (!superAdmin || !(await EncryptHelper.compare(payload.password, superAdmin.password))) {
      throw new BadRequestException('Credenciales incorrectas')
    }

    if (!superAdmin.isActive) {
      throw new BadRequestException('Usuario deshabilitado')
    }

    const accessToken = await TokenHelper.generateJWT({ id: superAdmin.id })
    const tokens: TokenEntity = {
      accessToken,
    }

    return tokens
  }
}
