import { Injectable } from '@/core/api/di/decorators'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { BadRequestException } from '@/libs/domain/errors'
import { CustomerRepository } from '@/libs/domain/repositories/tenant/customer.repository'
import { UserRepository } from '@/libs/domain/repositories/tenant/user.repository'

@Injectable()
export class DeleteCustomerUseCase {
  constructor(
    private readonly userRepository: UserRepository,
    private readonly customerRepository: CustomerRepository
  ) {}

  async run(id: string, { tenant }: RequestContext): Promise<void> {
    const user = await this.userRepository.findOne(
      {
        customer: {
          id,
        },
      },
      tenant.id
    )

    if (!user) {
      throw new BadRequestException('No existe usuario relacionado.')
    }

    if (!user.employee && !user.driver) {
      await this.userRepository.delete(
        {
          customer: {
            id,
          },
        },
        tenant.id
      )
      return
    }

    await this.customerRepository.delete(
      {
        id,
      },
      tenant.id
    )
  }
}
