import { Injectable } from '@/core/api/di/decorators'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { CustomerEntity } from '@/libs/domain/entities/tenant/customer.entity'
import { EncryptHelper } from '@/libs/domain/helpers/encrypt.helper'
import { CustomerRepository } from '@/libs/domain/repositories/tenant/customer.repository'
import { UserRepository } from '@/libs/domain/repositories/tenant/user.repository'

@Injectable()
export class UpdateCustomerUseCase {
  constructor(
    private readonly customerRepository: CustomerRepository,
    private readonly userRepository: UserRepository
  ) {}

  async run(
    id: string,
    { user: updatedUser, ...payload }: CustomerEntity,
    { tenant }: RequestContext
  ): Promise<CustomerEntity> {
    const customer = await this.customerRepository.findOne({ id }, tenant.id)

    if (updatedUser?.password) {
      updatedUser.password = await EncryptHelper.hash(updatedUser.password)
    }

    await this.userRepository.save({ id: customer!.user!.id, ...updatedUser }, tenant.id) // cascade mode disabled

    return await this.customerRepository.save({ id, ...payload }, tenant.id)
  }
}
