import { Injectable } from '@/core/api/di/decorators'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { OrderStatus } from '@/libs/domain/entities/tenant/_types'
import { FormEntity } from '@/libs/domain/entities/tenant/form.entity'
import { OrderEntity } from '@/libs/domain/entities/tenant/order.entity'
import { BadRequestException } from '@/libs/domain/errors'
import { FormTemplateRepository } from '@/libs/domain/repositories/tenant/form-template.repository'
import { FormRepository } from '@/libs/domain/repositories/tenant/form.repository'
import { OrderRepository } from '@/libs/domain/repositories/tenant/order.repository'

@Injectable()
export class CreateOrderUseCase {
  constructor(
    private readonly orderRepository: OrderRepository,
    private readonly formTemplateRepository: FormTemplateRepository,
    private readonly formRepository: FormRepository
  ) {}

  async run(
    payload: Pick<FormEntity, 'fields'>,
    { tenant, user }: RequestContext
  ): Promise<OrderEntity> {
    const formTemplate = await this.formTemplateRepository.findOne({}, tenant.id)

    const fieldsTransformed = formTemplate!.fields.map(field => {
      const value = payload.fields.find(({ id }) => id === field.id)?.value

      if (field.isRequired && !value) {
        throw new BadRequestException('Campo invalido.')
      }
      return { ...field, value }
    })

    const form = await this.formRepository.save({ fields: fieldsTransformed }, tenant.id)

    return this.orderRepository.save(
      {
        status: OrderStatus.requested,
        customer: {
          id: user?.customer?.id,
        },
        form,
      },
      tenant.id
    )
  }
}
