import { Injectable } from '@/core/api/di/decorators'
import { RequestContext } from '@/libs/domain/contexts/request.context'
import { OffsetCriteria } from '@/libs/domain/criteria/criteria'
import { FilterOperator } from '@/libs/domain/criteria/filters'
import { OrderEntity } from '@/libs/domain/entities/tenant/order.entity'
import { OrderRepository } from '@/libs/domain/repositories/tenant/order.repository'

@Injectable()
export class ListOrdersUseCase {
  constructor(private readonly orderRepository: OrderRepository) {}

  async run(
    criteria: OffsetCriteria,
    { tenant, user }: RequestContext
  ): Promise<{ total: number; results: OrderEntity[] }> {
    if (user?.customer) {
      criteria.addFilter({
        field: 'customer.id',
        operator: FilterOperator.EQUAL,
        value: user.customer.id,
      })
    }
    return await this.orderRepository.findByOffsetCriteria(criteria, tenant.id)
  }
}
