import { Injectable } from '@/core/api/di/decorators'
import { RequestContext } from '../../../domain/contexts/request.context'
import { ConnectionRepository } from '../../../domain/repositories/master/connection.repository'
import { DefaultFieldRepository } from '../../../domain/repositories/master/default-field.repository'
import { SuperAdminRepository } from '../../../domain/repositories/master/super-admin.repository'
import { TenantCategoryRepository } from '../../../domain/repositories/master/tenant-category.repsitory'
import { TenantRepository } from '../../../domain/repositories/master/tenant.repository'
import { CustomerRepository } from '../../../domain/repositories/tenant/customer.repository'
import { DriverRepository } from '../../../domain/repositories/tenant/driver.repository'
import { EmployeeRepository } from '../../../domain/repositories/tenant/employee.repository'
import { InvoiceRepository } from '../../../domain/repositories/tenant/invoice.repository'
import { OrderQuoteRepository } from '../../../domain/repositories/tenant/order-quote.repository'
import { OrderRepository } from '../../../domain/repositories/tenant/order.repository'
import { PermissionRepository } from '../../../domain/repositories/tenant/permission.repository'
import { RoleRepository } from '../../../domain/repositories/tenant/role.repository'
import { ShippingReceiverRepository } from '../../../domain/repositories/tenant/shipping-receiver.repository'
import { ShippingStatusHistoryRepository } from '../../../domain/repositories/tenant/shipping-status-history.repository'
import { ShippingRepository } from '../../../domain/repositories/tenant/shipping.repository'
import { TransportCompanyRepository } from '../../../domain/repositories/tenant/transport-company.repository'
import { TransportPaymentRepository } from '../../../domain/repositories/tenant/transport-payment.repository'
import { UserRepository } from '../../../domain/repositories/tenant/user.repository'
import { OrderStatusHistoryRepository } from '../../../domain/repositories/tenant/order-status-history.repository'
import { NotFoundException } from '../../../domain/errors'

export type EntityType =
  | 'connection'
  | 'default-field'
  | 'super-admin'
  | 'tenant-category'
  | 'tenant'
  | 'customer'
  | 'driver'
  | 'employee'
  | 'invoice'
  | 'order-quote'
  | 'order-status-history'
  | 'order'
  | 'permission'
  | 'role'
  | 'shipping-receiver'
  | 'shipping-status-history'
  | 'shipping'
  | 'transport-company'
  | 'transport-payment'
  | 'user'

@Injectable()
export class ValidateIdExistsUseCase {
  constructor(
    private readonly connectionRepository: ConnectionRepository,
    private readonly defaultFieldRepository: DefaultFieldRepository,
    private readonly superAdminRepository: SuperAdminRepository,
    private readonly tenantCategoryRepository: TenantCategoryRepository,
    private readonly tenantRepository: TenantRepository,
    private readonly customerRepository: CustomerRepository,
    private readonly driverRepository: DriverRepository,
    private readonly employeeRepository: EmployeeRepository,
    private readonly invoiceRepository: InvoiceRepository,
    private readonly orderQuoteRepository: OrderQuoteRepository,
    private readonly orderStatusHistoryRepository: OrderStatusHistoryRepository,
    private readonly orderRepository: OrderRepository,
    private readonly permissionRepository: PermissionRepository,
    private readonly roleRepository: RoleRepository,
    private readonly shippingReceiverRepository: ShippingReceiverRepository,
    private readonly shippingStatusHistoryRepository: ShippingStatusHistoryRepository,
    private readonly shippingRepository: ShippingRepository,
    private readonly transportCompanyRepository: TransportCompanyRepository,
    private readonly transportPaymentRepository: TransportPaymentRepository,
    private readonly userRepository: UserRepository
  ) {}

  async run(
    { entity, id }: { entity: EntityType; id: string },
    { tenant, user }: RequestContext
  ): Promise<void> {
    const pathsRepository: {
      [key in EntityType]: {
        name: string
        getEntity: () => Promise<unknown>
      }
    } = {
      connection: {
        name: 'Conexión',
        getEntity: () => this.connectionRepository.findOne({ id }),
      },
      'default-field': {
        name: 'Campo',
        getEntity: () => this.defaultFieldRepository.findOne({ id }),
      },
      'super-admin': {
        name: 'Super administrador',
        getEntity: () => this.superAdminRepository.findOne({ id }),
      },
      'tenant-category': {
        name: 'Categoria de inquilino',
        getEntity: () => this.tenantCategoryRepository.findOne({ id }),
      },
      tenant: {
        name: 'Inquilino',
        getEntity: () => this.tenantRepository.findOne({ id }),
      },
      customer: {
        name: 'Cliente',
        getEntity: () => this.customerRepository.findOne({ id }, tenant.id),
      },
      driver: {
        name: 'Conductor',
        getEntity: () => this.driverRepository.findOne({ id }, tenant.id),
      },
      employee: {
        name: 'Empleado',
        getEntity: () => this.employeeRepository.findOne({ id }, tenant.id),
      },
      invoice: {
        name: 'Factura',
        getEntity: () => this.invoiceRepository.findOne({ id }, tenant.id),
      },
      'order-quote': {
        name: 'Cotizacion',
        getEntity: () => this.orderQuoteRepository.findOne({ id }, tenant.id),
      },
      'order-status-history': {
        name: 'Historial de estado de orden',
        getEntity: () => this.orderStatusHistoryRepository.findOne({ id }, tenant.id),
      },
      order: {
        name: 'Pedido',
        getEntity: () => this.orderRepository.findOne({ id }, tenant.id),
      },
      permission: {
        name: 'Permiso',
        getEntity: () => this.permissionRepository.findOne({ id }, tenant.id),
      },
      role: {
        name: 'Rol',
        getEntity: () => this.roleRepository.findOne({ id }, tenant.id),
      },
      'shipping-receiver': {
        name: 'Receptor de envio',
        getEntity: () => this.shippingReceiverRepository.findOne({ id }, tenant.id),
      },

      'shipping-status-history': {
        name: 'Historial de estado de envio',
        getEntity: () => this.shippingStatusHistoryRepository.findOne({ id }, tenant.id),
      },
      shipping: {
        name: 'Envio',
        getEntity: () => this.shippingRepository.findOne({ id }, tenant.id),
      },
      'transport-company': {
        name: 'Empresa de transporte',
        getEntity: () => this.transportCompanyRepository.findOne({ id }, tenant.id),
      },
      'transport-payment': {
        name: 'Pago de transporte',
        getEntity: () => this.transportPaymentRepository.findOne({ id }, tenant.id),
      },
      user: {
        name: 'Usuario',
        getEntity: () => this.userRepository.findOne({ id }, tenant.id),
      },
    }
    if (!pathsRepository[entity]) {
      throw new Error(`Collection path ${entity} dont exists in 'pathsRepository' object.`) // error 500
    }

    const _entity = await pathsRepository[entity].getEntity()

    if (!_entity) {
      throw new NotFoundException(`${pathsRepository[entity].name} no encontrado.`)
    }
  }
}
