import { ParseHelper } from '../helpers/parse.helper'
import { TokenHelper } from '../helpers/token.helper'

export class CursorPagination {
  static defaultPageSize = 15

  pageSize: number
  cursor?: string

  field: string
  // fields: string[]
  orderType: 'asc' | 'desc'

  private constructor({
    pageSize = CursorPagination.defaultPageSize,
    cursor,

    field = 'createdAt',
    // fields = ['createdAt', 'id'], // to support multiples fields must be create a index  - multiple column.
    // See: https://dba.stackexchange.com/questions/205384/mysql-uuid-created-at-cursor-based-pagination
    // use typeorm query builder
    orderType = 'desc',
  }: {
    pageSize: number
    cursor?: string
    field?: string

    orderType?: 'asc' | 'desc'
  }) {
    this.pageSize = Number(pageSize)
    this.cursor = cursor

    this.orderType = orderType
    this.field = field
  }

  static fromPrimitives(
    primitives: any,
    order?: { field: string; orderType: 'asc' | 'desc' }
  ): CursorPagination {
    return new CursorPagination({ ...primitives, ...order })
  }

  async encodeCursor(payload: { [key: string]: string }): Promise<string> {
    if (!payload[this.field]) {
      throw new Error(`encode payload must be have payload.${this.field} defined`)
    }

    return await TokenHelper.generateJWT(payload)
  }

  async decodeCursor(): Promise<{ [key: string]: string | number | Date }> {
    const payload = await TokenHelper.parseJWT(this.cursor!)

    if (!payload) {
      throw new Error('Invalid `cursor`.')
    }

    if (!payload[this.field]) {
      throw new Error(`Invalid \`cursor\`, decoded cursor must be have \`${this.field}\` defined.`)
    }

    return {
      [this.field]: ParseHelper.parsePrimitive(payload[this.field]) as string | number | Date,
    }
  }
}
