import Mail from 'nodemailer/lib/mailer'

import { MailSendPayload } from '../services/mailer.service'

export type MailOptions = Mail.Options & MailSendPayload

export class MailMessageBuilder {
  private mailOptions: MailSendPayload

  elements: { type: 'title' | 'line' | 'action'; text?: string; name?: string; url?: string }[] = []

  constructor(mailOptions: Mail.Options) {
    this.mailOptions = { ...mailOptions, template: 'mail-message-builder' }
  }

  addTitle(text: string) {
    this.elements.push({
      type: 'title',
      text,
    })
    return this
  }

  addLine(text: string) {
    this.elements.push({
      type: 'line',
      text,
    })
    return this
  }

  addAction(name: string, url: string) {
    this.elements.push({
      type: 'action',
      name,
      url,
    })
    return this
  }

  build() {
    this.mailOptions.ctx = {
      elements: this.elements,
    }
    return this.mailOptions
  }
}
