import { DeepPartial } from 'utility-types'
import { CursorCriteria, OffsetCriteria } from '../../criteria/criteria'
import { BaseMasterEntity } from '../../entities/master/_base-master.entity'

export abstract class BaseMasterRepository<Entity extends BaseMasterEntity> {
  abstract save(entity: DeepPartial<Entity>): Promise<Entity>

  abstract delete(entity: DeepPartial<Entity>): Promise<void>

  abstract findOne(entity: DeepPartial<Entity>): Promise<Entity | null>

  abstract findOneOrCreate(where: DeepPartial<Entity>, entity: DeepPartial<Entity>): Promise<Entity>

  abstract find(): Promise<Entity[]>

  abstract findByCursorCriteria(
    criteria: CursorCriteria
  ): Promise<{ cursor: string | null; results: Entity[] }>

  abstract findByOffsetCriteria(
    criteria: OffsetCriteria
  ): Promise<{ total: number; results: Entity[] }>
}
