import { MigrationInterface, QueryRunner } from "typeorm";

export class Auto1712851329537 implements MigrationInterface {
    name = 'Auto1712851329537'

    public async up(queryRunner: QueryRunner): Promise<void> {
        await queryRunner.query(`CREATE TABLE "tenant"."user" ("rut" character varying NOT NULL, "password" character varying NOT NULL, "email" character varying NOT NULL, "firstName" character varying NOT NULL, "lastName" character varying NOT NULL, "phoneNumber" character varying NOT NULL, "isActive" boolean NOT NULL DEFAULT false, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, CONSTRAINT "UQ_9f839e522b3b8c8c8223cde81db" UNIQUE ("rut"), CONSTRAINT "UQ_e12875dfb3b1d92d7d7c5377e22" UNIQUE ("email"), CONSTRAINT "PK_cace4a159ff9f2512dd42373760" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "user_TENANT_ID" ON "tenant"."user" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."transport_payment" ("amount" integer NOT NULL, "commission" integer NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "orderId" uuid, "transportCompanyId" uuid, "employeeId" uuid, CONSTRAINT "PK_3c668d34fbc025a4f738738fc34" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "transport_payment_TENANT_ID" ON "tenant"."transport_payment" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."transport_company" ("rut" character varying NOT NULL, "legalName" character varying NOT NULL, "legalAddress" character varying NOT NULL, "phoneNumber" character varying NOT NULL, "email" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "companyId" uuid, CONSTRAINT "UQ_ff164b38a79da486d8a3bc707e3" UNIQUE ("rut"), CONSTRAINT "UQ_6a6bf3bca88c90ce86841c13506" UNIQUE ("email"), CONSTRAINT "PK_537319775514aba1fe82e0d9cf8" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "transport_company_TENANT_ID" ON "tenant"."transport_company" ("tenantId") `);
        await queryRunner.query(`CREATE TYPE "tenant"."shipping_status_enum" AS ENUM('created', 'assigned', 'inTransit', 'delivered')`);
        await queryRunner.query(`CREATE TABLE "tenant"."shipping" ("trackingNumber" integer NOT NULL, "price" integer NOT NULL, "status" "tenant"."shipping_status_enum" NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "transportCompanyId" uuid, "driverId" uuid, "orderId" uuid, "invoiceId" uuid, CONSTRAINT "PK_0dc6ac92ee9cbc2c1611d77804c" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "shipping_TENANT_ID" ON "tenant"."shipping" ("tenantId") `);
        await queryRunner.query(`CREATE TYPE "tenant"."shipping_status_history_status_enum" AS ENUM('created', 'assigned', 'inTransit', 'delivered')`);
        await queryRunner.query(`CREATE TABLE "tenant"."shipping_status_history" ("status" "tenant"."shipping_status_history_status_enum" NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "shippingId" uuid, CONSTRAINT "PK_16eaaec6ae488bda68968272a8b" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "shipping_status_history_TENANT_ID" ON "tenant"."shipping_status_history" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."shipping_receiver" ("rut" character varying NOT NULL, "firstName" character varying NOT NULL, "lastName" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "shippingId" uuid, CONSTRAINT "REL_df623a320df61a3db4f50bd469" UNIQUE ("shippingId"), CONSTRAINT "PK_4d30b2d61b8a6beecc9fffed286" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "shipping_receiver_TENANT_ID" ON "tenant"."shipping_receiver" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."role" ("name" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, CONSTRAINT "UQ_ae4578dcaed5adff96595e61660" UNIQUE ("name"), CONSTRAINT "PK_b36bcfe02fc8de3c57a8b2391c2" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "role_TENANT_ID" ON "tenant"."role" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."permission" ("name" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, CONSTRAINT "UQ_240853a0c3353c25fb12434ad33" UNIQUE ("name"), CONSTRAINT "PK_3b8b97af9d9d8807e41e6f48362" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "permission_TENANT_ID" ON "tenant"."permission" ("tenantId") `);
        await queryRunner.query(`CREATE TYPE "tenant"."order_status_enum" AS ENUM('requested', 'quoted', 'accepted', 'declined', 'inProgress', 'completed')`);
        await queryRunner.query(`CREATE TABLE "tenant"."order" ("price" integer NOT NULL, "regularPrice" integer NOT NULL, "status" "tenant"."order_status_enum" NOT NULL, "declineReason" character varying, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "customerId" uuid, "companyId" uuid, CONSTRAINT "PK_1031171c13130102495201e3e20" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "order_TENANT_ID" ON "tenant"."order" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."order_to_field" ("value" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "orderId" uuid, "fieldId" uuid, CONSTRAINT "PK_e425cfc3d89bc8194c31758da0a" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "order_to_field_TENANT_ID" ON "tenant"."order_to_field" ("tenantId") `);
        await queryRunner.query(`CREATE TYPE "tenant"."order_status_history_status_enum" AS ENUM('requested', 'quoted', 'accepted', 'declined', 'inProgress', 'completed')`);
        await queryRunner.query(`CREATE TABLE "tenant"."order_status_history" ("status" "tenant"."order_status_history_status_enum" NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "orderId" uuid, CONSTRAINT "PK_e6c66d853f155531985fc4f6ec8" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "order_status_history_TENANT_ID" ON "tenant"."order_status_history" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."order_quote" ("description" text, "price" integer NOT NULL, "code" integer NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "orderId" uuid, CONSTRAINT "REL_fc6abebe4b4647ec7a1a11ff88" UNIQUE ("orderId"), CONSTRAINT "PK_f970cee09c6fd9b843822103273" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "order_quote_TENANT_ID" ON "tenant"."order_quote" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."invoice" ("pdfUrl" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "orderId" uuid, CONSTRAINT "PK_15d25c200d9bcd8a33f698daf18" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "invoice_TENANT_ID" ON "tenant"."invoice" ("tenantId") `);
        await queryRunner.query(`CREATE TYPE "tenant"."field_type_enum" AS ENUM('text', 'textArea', 'number', 'date')`);
        await queryRunner.query(`CREATE TABLE "tenant"."field" ("label" character varying NOT NULL, "name" character varying NOT NULL, "placeholder" character varying NOT NULL, "isRequired" boolean NOT NULL, "span" integer NOT NULL, "order" integer NOT NULL, "type" "tenant"."field_type_enum" NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "companyId" uuid, CONSTRAINT "PK_39379bba786d7a75226b358f81e" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "field_TENANT_ID" ON "tenant"."field" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."employee" ("id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "userId" uuid, "companyId" uuid, CONSTRAINT "REL_f4b0d329c4a3cf79ffe9d56504" UNIQUE ("userId"), CONSTRAINT "PK_3c2bc72f03fd5abbbc5ac169498" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "employee_TENANT_ID" ON "tenant"."employee" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."driver" ("id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "userId" uuid, "transportCompanyId" uuid, CONSTRAINT "REL_abf4fe92b1ed7d4ffa2d4e8045" UNIQUE ("userId"), CONSTRAINT "PK_61de71a8d217d585ecd5ee3d065" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "driver_TENANT_ID" ON "tenant"."driver" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."customer" ("id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, "userId" uuid, "companyId" uuid, CONSTRAINT "REL_3f62b42ed23958b120c235f74d" UNIQUE ("userId"), CONSTRAINT "PK_a7a13f4cacb744524e44dfdad32" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "customer_TENANT_ID" ON "tenant"."customer" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."company" ("rut" character varying NOT NULL, "legalName" character varying NOT NULL, "legalAddress" character varying NOT NULL, "phoneNumber" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid NOT NULL, CONSTRAINT "PK_056f7854a7afdba7cbd6d45fc20" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE INDEX "company_TENANT_ID" ON "tenant"."company" ("tenantId") `);
        await queryRunner.query(`CREATE TABLE "master"."tenant" ("name" character varying NOT NULL, "subdomain" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "categoryId" uuid, CONSTRAINT "UQ_56211336b5ff35fd944f2259173" UNIQUE ("name"), CONSTRAINT "UQ_a1da63250e49e1cfb2cf9bacfaf" UNIQUE ("subdomain"), CONSTRAINT "PK_da8c6efd67bb301e810e56ac139" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE TABLE "master"."tenant_category" ("name" character varying NOT NULL, "description" text, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), CONSTRAINT "UQ_6d5bc4902d2e216e78b7229f4dc" UNIQUE ("name"), CONSTRAINT "PK_eda742e5d62e5f2f68cd6b75dbd" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE TABLE "master"."super_admin" ("email" character varying NOT NULL, "password" character varying NOT NULL, "isActive" boolean NOT NULL DEFAULT false, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), CONSTRAINT "UQ_1ce171ef935f892c7f13004f232" UNIQUE ("email"), CONSTRAINT "PK_3c4fab866f4c62a54ee1ebb1fe3" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE TYPE "master"."default_field_type_enum" AS ENUM('text', 'textArea', 'number', 'date')`);
        await queryRunner.query(`CREATE TABLE "master"."default_field" ("label" character varying NOT NULL, "name" character varying NOT NULL, "placeholder" character varying NOT NULL, "span" integer NOT NULL, "order" integer NOT NULL, "type" "master"."default_field_type_enum" NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "categoryId" uuid, CONSTRAINT "PK_4a3be7168ecfe3eb5866131a466" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE TABLE "master"."connection" ("dbHost" character varying NOT NULL, "dbName" character varying NOT NULL, "dbPassword" character varying NOT NULL, "dbPort" character varying NOT NULL, "dbUser" character varying NOT NULL, "id" uuid NOT NULL DEFAULT uuid_generate_v4(), "createdAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "updatedAt" TIMESTAMP(3) WITH TIME ZONE NOT NULL DEFAULT now(), "tenantId" uuid, CONSTRAINT "REL_9e4e433029611513d743bdaaaf" UNIQUE ("tenantId"), CONSTRAINT "PK_be611ce8b8cf439091c82a334b2" PRIMARY KEY ("id"))`);
        await queryRunner.query(`CREATE TABLE "tenant"."user_roles_role" ("userId" uuid NOT NULL, "roleId" uuid NOT NULL, CONSTRAINT "PK_b47cd6c84ee205ac5a713718292" PRIMARY KEY ("userId", "roleId"))`);
        await queryRunner.query(`CREATE INDEX "IDX_5f9286e6c25594c6b88c108db7" ON "tenant"."user_roles_role" ("userId") `);
        await queryRunner.query(`CREATE INDEX "IDX_4be2f7adf862634f5f803d246b" ON "tenant"."user_roles_role" ("roleId") `);
        await queryRunner.query(`CREATE TABLE "tenant"."role_permissions_permission" ("roleId" uuid NOT NULL, "permissionId" uuid NOT NULL, CONSTRAINT "PK_b817d7eca3b85f22130861259dd" PRIMARY KEY ("roleId", "permissionId"))`);
        await queryRunner.query(`CREATE INDEX "IDX_b36cb2e04bc353ca4ede00d87b" ON "tenant"."role_permissions_permission" ("roleId") `);
        await queryRunner.query(`CREATE INDEX "IDX_bfbc9e263d4cea6d7a8c9eb3ad" ON "tenant"."role_permissions_permission" ("permissionId") `);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_payment" ADD CONSTRAINT "FK_72b3c4cb94179dedcb43d6afb8e" FOREIGN KEY ("orderId") REFERENCES "tenant"."order"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_payment" ADD CONSTRAINT "FK_f75e58e349e5dc98a98bbf20b72" FOREIGN KEY ("transportCompanyId") REFERENCES "tenant"."transport_company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_payment" ADD CONSTRAINT "FK_f7a856ce8bd932432ca5666ada9" FOREIGN KEY ("employeeId") REFERENCES "tenant"."employee"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_company" ADD CONSTRAINT "FK_b8f3e56079122e4d8abcb6f40a0" FOREIGN KEY ("companyId") REFERENCES "tenant"."company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" ADD CONSTRAINT "FK_10157ea323c5150d380f93d491b" FOREIGN KEY ("transportCompanyId") REFERENCES "tenant"."transport_company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" ADD CONSTRAINT "FK_89bcf86bd5319a321eaf018da36" FOREIGN KEY ("driverId") REFERENCES "tenant"."driver"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" ADD CONSTRAINT "FK_ca6a07e6f19abf7a0f2fadf62eb" FOREIGN KEY ("orderId") REFERENCES "tenant"."order"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" ADD CONSTRAINT "FK_5be0c28391eaed8a5e1ce3b8dfd" FOREIGN KEY ("invoiceId") REFERENCES "tenant"."invoice"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping_status_history" ADD CONSTRAINT "FK_0074fdf560f6d6acfa9f3719a15" FOREIGN KEY ("shippingId") REFERENCES "tenant"."shipping"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping_receiver" ADD CONSTRAINT "FK_df623a320df61a3db4f50bd4693" FOREIGN KEY ("shippingId") REFERENCES "tenant"."shipping"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."order" ADD CONSTRAINT "FK_124456e637cca7a415897dce659" FOREIGN KEY ("customerId") REFERENCES "tenant"."customer"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."order" ADD CONSTRAINT "FK_75c9ce255f89db219917013e0fc" FOREIGN KEY ("companyId") REFERENCES "tenant"."company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_to_field" ADD CONSTRAINT "FK_63542abff989322d10ecc73a42b" FOREIGN KEY ("orderId") REFERENCES "tenant"."order"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_to_field" ADD CONSTRAINT "FK_dfc5d5cb0fda0c1ec5c30372b66" FOREIGN KEY ("fieldId") REFERENCES "tenant"."field"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_status_history" ADD CONSTRAINT "FK_689db3835e5550e68d26ca32676" FOREIGN KEY ("orderId") REFERENCES "tenant"."order"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_quote" ADD CONSTRAINT "FK_fc6abebe4b4647ec7a1a11ff88e" FOREIGN KEY ("orderId") REFERENCES "tenant"."order"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."invoice" ADD CONSTRAINT "FK_f494ce6746b91e9ec9562af4857" FOREIGN KEY ("orderId") REFERENCES "tenant"."order"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."field" ADD CONSTRAINT "FK_48803b1458c40a5e92b6deb5612" FOREIGN KEY ("companyId") REFERENCES "tenant"."company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."employee" ADD CONSTRAINT "FK_f4b0d329c4a3cf79ffe9d565047" FOREIGN KEY ("userId") REFERENCES "tenant"."user"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."employee" ADD CONSTRAINT "FK_26c3d513e0832e5abbbdd3d2a88" FOREIGN KEY ("companyId") REFERENCES "tenant"."company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."driver" ADD CONSTRAINT "FK_abf4fe92b1ed7d4ffa2d4e8045a" FOREIGN KEY ("userId") REFERENCES "tenant"."user"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."driver" ADD CONSTRAINT "FK_3091fae4fbafa3b954184af7963" FOREIGN KEY ("transportCompanyId") REFERENCES "tenant"."transport_company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."customer" ADD CONSTRAINT "FK_3f62b42ed23958b120c235f74df" FOREIGN KEY ("userId") REFERENCES "tenant"."user"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."customer" ADD CONSTRAINT "FK_a9d874b83a7879be8538bf08b09" FOREIGN KEY ("companyId") REFERENCES "tenant"."company"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "master"."tenant" ADD CONSTRAINT "FK_5ab4ba78a42384b148489e423ae" FOREIGN KEY ("categoryId") REFERENCES "master"."tenant_category"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "master"."default_field" ADD CONSTRAINT "FK_612307acada5d2bfb7a252cf19e" FOREIGN KEY ("categoryId") REFERENCES "master"."tenant_category"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "master"."connection" ADD CONSTRAINT "FK_9e4e433029611513d743bdaaaf2" FOREIGN KEY ("tenantId") REFERENCES "master"."tenant"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`);
        await queryRunner.query(`ALTER TABLE "tenant"."user_roles_role" ADD CONSTRAINT "FK_5f9286e6c25594c6b88c108db77" FOREIGN KEY ("userId") REFERENCES "tenant"."user"("id") ON DELETE CASCADE ON UPDATE CASCADE`);
        await queryRunner.query(`ALTER TABLE "tenant"."user_roles_role" ADD CONSTRAINT "FK_4be2f7adf862634f5f803d246b8" FOREIGN KEY ("roleId") REFERENCES "tenant"."role"("id") ON DELETE CASCADE ON UPDATE CASCADE`);
        await queryRunner.query(`ALTER TABLE "tenant"."role_permissions_permission" ADD CONSTRAINT "FK_b36cb2e04bc353ca4ede00d87b9" FOREIGN KEY ("roleId") REFERENCES "tenant"."role"("id") ON DELETE CASCADE ON UPDATE CASCADE`);
        await queryRunner.query(`ALTER TABLE "tenant"."role_permissions_permission" ADD CONSTRAINT "FK_bfbc9e263d4cea6d7a8c9eb3ad2" FOREIGN KEY ("permissionId") REFERENCES "tenant"."permission"("id") ON DELETE CASCADE ON UPDATE CASCADE`);
    }

    public async down(queryRunner: QueryRunner): Promise<void> {
        await queryRunner.query(`ALTER TABLE "tenant"."role_permissions_permission" DROP CONSTRAINT "FK_bfbc9e263d4cea6d7a8c9eb3ad2"`);
        await queryRunner.query(`ALTER TABLE "tenant"."role_permissions_permission" DROP CONSTRAINT "FK_b36cb2e04bc353ca4ede00d87b9"`);
        await queryRunner.query(`ALTER TABLE "tenant"."user_roles_role" DROP CONSTRAINT "FK_4be2f7adf862634f5f803d246b8"`);
        await queryRunner.query(`ALTER TABLE "tenant"."user_roles_role" DROP CONSTRAINT "FK_5f9286e6c25594c6b88c108db77"`);
        await queryRunner.query(`ALTER TABLE "master"."connection" DROP CONSTRAINT "FK_9e4e433029611513d743bdaaaf2"`);
        await queryRunner.query(`ALTER TABLE "master"."default_field" DROP CONSTRAINT "FK_612307acada5d2bfb7a252cf19e"`);
        await queryRunner.query(`ALTER TABLE "master"."tenant" DROP CONSTRAINT "FK_5ab4ba78a42384b148489e423ae"`);
        await queryRunner.query(`ALTER TABLE "tenant"."customer" DROP CONSTRAINT "FK_a9d874b83a7879be8538bf08b09"`);
        await queryRunner.query(`ALTER TABLE "tenant"."customer" DROP CONSTRAINT "FK_3f62b42ed23958b120c235f74df"`);
        await queryRunner.query(`ALTER TABLE "tenant"."driver" DROP CONSTRAINT "FK_3091fae4fbafa3b954184af7963"`);
        await queryRunner.query(`ALTER TABLE "tenant"."driver" DROP CONSTRAINT "FK_abf4fe92b1ed7d4ffa2d4e8045a"`);
        await queryRunner.query(`ALTER TABLE "tenant"."employee" DROP CONSTRAINT "FK_26c3d513e0832e5abbbdd3d2a88"`);
        await queryRunner.query(`ALTER TABLE "tenant"."employee" DROP CONSTRAINT "FK_f4b0d329c4a3cf79ffe9d565047"`);
        await queryRunner.query(`ALTER TABLE "tenant"."field" DROP CONSTRAINT "FK_48803b1458c40a5e92b6deb5612"`);
        await queryRunner.query(`ALTER TABLE "tenant"."invoice" DROP CONSTRAINT "FK_f494ce6746b91e9ec9562af4857"`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_quote" DROP CONSTRAINT "FK_fc6abebe4b4647ec7a1a11ff88e"`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_status_history" DROP CONSTRAINT "FK_689db3835e5550e68d26ca32676"`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_to_field" DROP CONSTRAINT "FK_dfc5d5cb0fda0c1ec5c30372b66"`);
        await queryRunner.query(`ALTER TABLE "tenant"."order_to_field" DROP CONSTRAINT "FK_63542abff989322d10ecc73a42b"`);
        await queryRunner.query(`ALTER TABLE "tenant"."order" DROP CONSTRAINT "FK_75c9ce255f89db219917013e0fc"`);
        await queryRunner.query(`ALTER TABLE "tenant"."order" DROP CONSTRAINT "FK_124456e637cca7a415897dce659"`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping_receiver" DROP CONSTRAINT "FK_df623a320df61a3db4f50bd4693"`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping_status_history" DROP CONSTRAINT "FK_0074fdf560f6d6acfa9f3719a15"`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" DROP CONSTRAINT "FK_5be0c28391eaed8a5e1ce3b8dfd"`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" DROP CONSTRAINT "FK_ca6a07e6f19abf7a0f2fadf62eb"`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" DROP CONSTRAINT "FK_89bcf86bd5319a321eaf018da36"`);
        await queryRunner.query(`ALTER TABLE "tenant"."shipping" DROP CONSTRAINT "FK_10157ea323c5150d380f93d491b"`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_company" DROP CONSTRAINT "FK_b8f3e56079122e4d8abcb6f40a0"`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_payment" DROP CONSTRAINT "FK_f7a856ce8bd932432ca5666ada9"`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_payment" DROP CONSTRAINT "FK_f75e58e349e5dc98a98bbf20b72"`);
        await queryRunner.query(`ALTER TABLE "tenant"."transport_payment" DROP CONSTRAINT "FK_72b3c4cb94179dedcb43d6afb8e"`);
        await queryRunner.query(`DROP INDEX "tenant"."IDX_bfbc9e263d4cea6d7a8c9eb3ad"`);
        await queryRunner.query(`DROP INDEX "tenant"."IDX_b36cb2e04bc353ca4ede00d87b"`);
        await queryRunner.query(`DROP TABLE "tenant"."role_permissions_permission"`);
        await queryRunner.query(`DROP INDEX "tenant"."IDX_4be2f7adf862634f5f803d246b"`);
        await queryRunner.query(`DROP INDEX "tenant"."IDX_5f9286e6c25594c6b88c108db7"`);
        await queryRunner.query(`DROP TABLE "tenant"."user_roles_role"`);
        await queryRunner.query(`DROP TABLE "master"."connection"`);
        await queryRunner.query(`DROP TABLE "master"."default_field"`);
        await queryRunner.query(`DROP TYPE "master"."default_field_type_enum"`);
        await queryRunner.query(`DROP TABLE "master"."super_admin"`);
        await queryRunner.query(`DROP TABLE "master"."tenant_category"`);
        await queryRunner.query(`DROP TABLE "master"."tenant"`);
        await queryRunner.query(`DROP INDEX "tenant"."company_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."company"`);
        await queryRunner.query(`DROP INDEX "tenant"."customer_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."customer"`);
        await queryRunner.query(`DROP INDEX "tenant"."driver_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."driver"`);
        await queryRunner.query(`DROP INDEX "tenant"."employee_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."employee"`);
        await queryRunner.query(`DROP INDEX "tenant"."field_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."field"`);
        await queryRunner.query(`DROP TYPE "tenant"."field_type_enum"`);
        await queryRunner.query(`DROP INDEX "tenant"."invoice_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."invoice"`);
        await queryRunner.query(`DROP INDEX "tenant"."order_quote_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."order_quote"`);
        await queryRunner.query(`DROP INDEX "tenant"."order_status_history_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."order_status_history"`);
        await queryRunner.query(`DROP TYPE "tenant"."order_status_history_status_enum"`);
        await queryRunner.query(`DROP INDEX "tenant"."order_to_field_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."order_to_field"`);
        await queryRunner.query(`DROP INDEX "tenant"."order_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."order"`);
        await queryRunner.query(`DROP TYPE "tenant"."order_status_enum"`);
        await queryRunner.query(`DROP INDEX "tenant"."permission_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."permission"`);
        await queryRunner.query(`DROP INDEX "tenant"."role_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."role"`);
        await queryRunner.query(`DROP INDEX "tenant"."shipping_receiver_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."shipping_receiver"`);
        await queryRunner.query(`DROP INDEX "tenant"."shipping_status_history_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."shipping_status_history"`);
        await queryRunner.query(`DROP TYPE "tenant"."shipping_status_history_status_enum"`);
        await queryRunner.query(`DROP INDEX "tenant"."shipping_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."shipping"`);
        await queryRunner.query(`DROP TYPE "tenant"."shipping_status_enum"`);
        await queryRunner.query(`DROP INDEX "tenant"."transport_company_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."transport_company"`);
        await queryRunner.query(`DROP INDEX "tenant"."transport_payment_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."transport_payment"`);
        await queryRunner.query(`DROP INDEX "tenant"."user_TENANT_ID"`);
        await queryRunner.query(`DROP TABLE "tenant"."user"`);
    }

}
