import { ShippingEntity } from '@/libs/domain/entities/tenant/shipping.entity'
import { BaseTenantEntitySchema } from './_base-tenant-schema'
import { ShippingStatus } from '@/libs/domain/entities/tenant/_types'

export const shippingSchema = new BaseTenantEntitySchema<ShippingEntity>({
  name: 'shipping',
  columns: {
    trackingNumber: {
      type: Number,
    },
    price: {
      type: Number,
    },
    status: {
      type: 'enum',
      enum: ShippingStatus,
    },
  },
  relations: {
    transportCompany: {
      target: 'transportCompany',
      type: 'many-to-one',
    },
    driver: {
      target: 'driver',
      type: 'many-to-one',
    },
    order: {
      target: 'order',
      type: 'many-to-one',
    },
    invoice: {
      target: 'invoice',
      type: 'many-to-one',
    },
    shippingStatusHistories: {
      target: 'shippingStatusHistory',
      type: 'one-to-many',
      inverseSide: 'shipping',
    },
    shippingReceiver: {
      target: 'shippingReceiver',
      type: 'one-to-one',
      inverseSide: 'shipping',
    },
  },
})
