import { Injectable } from '@/core/api/di/decorators'
import { Seeder } from './_seeder'
import { TenantCategoryRepository } from '@/libs/domain/repositories/master/tenant-category.repsitory'
import { DefaultFieldRepository } from '@/libs/domain/repositories/master/default-field.repository'
import { TenantRepository } from '@/libs/domain/repositories/master/tenant.repository'
import { TenantCategoryEntity } from '@/libs/domain/entities/master/tenant-category.entity'
import { DefaultFieldType } from '@/libs/domain/entities/master/_types'
import { DefaultFieldEntity } from '@/libs/domain/entities/master/default-field.entity'
import { TenantEntity } from '@/libs/domain/entities/master/tenant.entity'
import { UserEntity } from '@/libs/domain/entities/tenant/user.entity'
import { UserRepository } from '@/libs/domain/repositories/tenant/user.repository'
import { RoleEntity } from '@/libs/domain/entities/tenant/role.entity'
import { EncryptHelper } from '@/libs/domain/helpers/encrypt.helper'
import { RoleRepository } from '@/libs/domain/repositories/tenant/role.repository'

import { TransportCompanyEntity } from '@/libs/domain/entities/tenant/transport-company.entity'
import { TransportCompanyRepository } from '@/libs/domain/repositories/tenant/transport-company.repository'
import { CustomerRepository } from '@/libs/domain/repositories/tenant/customer.repository'
import { EmployeeRepository } from '@/libs/domain/repositories/tenant/employee.repository'
import { DriverRepository } from '@/libs/domain/repositories/tenant/driver.repository'

import { appDataSource } from '../app-data-source'
import { SuperAdminEntity } from '@/libs/domain/entities/master/super-admin.entity'
import { SuperAdminRepository } from '@/libs/domain/repositories/master/super-admin.repository'
import { FormTemplateEntity } from '@/libs/domain/entities/tenant/form-template.entity'
import { FormTemplateRepository } from '@/libs/domain/repositories/tenant/form-template.repository'
import { DeepPartial } from 'utility-types'

export const testSuperAdminUser: SuperAdminEntity = {
  email: 'superadmin@gmail.com',
  password: '12345',
  isActive: true,
}

// RUBRO: TRANSPORTE

// REQUERIMIENTOS:

// - [ ] PESO (OBLIGATORIO)
// - [ ] ANCHO DE CARGA
// - [ ] ORIGEN (OBLIGATORIO)
// - [ ] DESTINO (OBLIGATORIO)
// - [ ] DISTANCIA(KM)(OBLIGATORIO)(GENERAL)
// - [ ] VOLUMEN (M3)(OBLIGATORIO)(CARGA PESADA)
// - [ ] FRAGILIDAD
// - [ ] SEGURO($25000)
// - [ ] FORMA DE PAGO(CONTADO,15 DIAS, 30 DIAS)
// - [ ] PRESUPUESTO: 15000(PARAMETRO)

export enum Role {
  adminEmployee = 'admin-employee',
  vendorEmployee = 'vendor-employee',
  customer = 'customer',
  driver = 'driver',
}

const testDefaultFields: DefaultFieldEntity[] = [
  {
    id: '4c698dd5-d7d1-47e7-ab10-809562731c7a',
    label: 'Peso',
    placeholder: 'Ingrese peso',
    order: 1,
    span: 24,
    type: DefaultFieldType.number,
  },
  {
    id: '2497cf38-f837-4a54-86b5-d04f050ed2af',
    label: 'Origen',
    placeholder: 'Ingrese origen',
    order: 2,
    span: 24,
    type: DefaultFieldType.text,
  },
  {
    id: 'd55c531c-6324-498a-a2af-8ae7e68b2a28',
    label: 'Destino',
    placeholder: 'Ingrese destino',
    order: 3,
    span: 24,
    type: DefaultFieldType.text,
  },
  {
    id: 'caeff8f9-c27e-4d87-b7ce-4c5879be2f85',
    label: 'Distancia (km)',
    placeholder: 'Ingrese distancia',
    order: 4,
    span: 24,
    type: DefaultFieldType.number,
  },
  {
    id: 'd1b92b4f-8cb0-4d5e-92ae-76fbce49e53c',
    label: 'Volumen (m³)',
    placeholder: 'Ingrese volumen',
    order: 5,
    span: 24,
    type: DefaultFieldType.number,
  },
]

const testFormTemplate: FormTemplateEntity = {
  fields: [
    ...testDefaultFields.map(
      defaultField =>
        ({
          ...defaultField,
          isRequired: true,
          isDefault: true,
        }) as FormTemplateEntity['fields'][0]
    ),
    {
      id: '12db3629-599b-4521-9f48-61e4de6e6c7d',
      label: 'Ancho de carga (m)',
      placeholder: 'Ingrese ancho de carga',
      order: 6,
      span: 24,
      isRequired: true,
      isDefault: false,
      type: DefaultFieldType.number,
    },
    {
      id: '2935332a-75dd-4813-ad9c-80c52c55e344',
      label: 'Fragilidad',
      placeholder: 'Ingrese fragilidad',
      order: 7,
      span: 24,
      isRequired: true,
      isDefault: false,
      type: DefaultFieldType.text,
    },
    {
      id: '598466f3-94e8-4af1-a17a-61ac66d94aa2',
      label: 'Seguro ($)',
      placeholder: 'Ingrese seguro',
      order: 8,
      span: 24,
      isRequired: false,
      isDefault: false,
      type: DefaultFieldType.number,
    },
    {
      id: 'e04cfbe1-1535-401f-854b-6c13ed861d84',
      label: 'Forma de pago (contado, 15 dias, 30 dias)',
      placeholder: 'Ingrese forma de pago',
      order: 9,
      span: 24,
      isRequired: true,
      isDefault: false,
      type: DefaultFieldType.text,
    },
    {
      id: '87c69288-757c-42aa-8e3a-1a890534457f',
      label: 'Presupuesto ($)',
      placeholder: 'Ingrese Presupuesto',
      order: 10,
      span: 24,
      isRequired: false,
      isDefault: false,
      type: DefaultFieldType.number,
    },
  ],
} as FormTemplateEntity

// todo
export const testTenantCategory: TenantCategoryEntity = {
  name: 'Transporte',
}

export const testTenant: TenantEntity = {
  rut: '00000000001',
  subdomain: 'civa',
  legalAddress: 'Avenida 28 de julio 456',
  legalName: 'Civa S.A.C',
  phoneNumber: '1235234234',
  category: testTenantCategory,
}

export const vendorEmployeeRole: Partial<RoleEntity> = {
  name: Role.vendorEmployee,
}

export const adminEmployeeRole: Partial<RoleEntity> = {
  name: Role.adminEmployee,
}

export const customerRole: Partial<RoleEntity> = {
  name: Role.customer,
}
export const driverRole: Partial<RoleEntity> = {
  name: Role.driver,
}

export const testAdminEmployee: DeepPartial<UserEntity> = {
  id: '63ababd2-d8f7-4c4a-b6d5-9278adf92c77',
  rut: '000000001',
  email: 'admin_employee@gmail.com',
  password: '12345',
  isActive: true,
  firstName: 'Dave',
  lastName: 'Brown',
  phoneNumber: '123456789',
  employee: {
    id: '1633dd48-325b-4b60-9614-93d47c5e30e4',
  },
  // roles: [adminEmployeeRole as RoleEntity],
}

export const testVendorEmployee: DeepPartial<UserEntity> = {
  id: '9b83a65c-6b35-4b6a-8587-23da079af269',
  rut: '000000002',
  email: 'vendor_employee@gmail.com',
  password: '12345',
  isActive: true,
  firstName: 'Randy',
  lastName: 'Malone',
  phoneNumber: '123456789',
  employee: {
    id: 'f2241547-bc18-4dc5-8042-915fea0f049f',
  },
  // roles: [vendorEmployeeRole as RoleEntity],
}

export const testCustomer: DeepPartial<UserEntity> = {
  id: 'cd9cd423-2d22-4e0c-92d1-57c2b74176f2',
  rut: '000000003',
  password: '12345',
  email: 'customer@gmail.com',
  isActive: true,
  firstName: 'James',
  lastName: 'Jones',
  phoneNumber: '123456789',
  customer: {
    id: '15613088-75b7-4d68-9d11-32e223126968',
  },
  // roles: [customerRole as RoleEntity],
}

export const testDriver: DeepPartial<UserEntity> = {
  id: '3e9285fd-d860-4248-92f4-7f786282f5bf',
  rut: '000000004',
  password: '12345',
  email: 'driver@gmail.com',
  isActive: true,
  firstName: 'Marco',
  lastName: 'Polo',
  phoneNumber: '123456789',
  driver: {
    id: '84cec742-bdca-4ec5-a928-400bd38da2e1',
  },
  // roles: [driverRole as RoleEntity],
}

export const testTransportCompany: TransportCompanyEntity = {
  email: 'test_tranport_company@gmail.com',
  legalAddress: 'Avenida 2 de octubre 234',
  legalName: 'Urbano Express',
  phoneNumber: '12312312312',
  rut: '000000000001',
} as TransportCompanyEntity

@Injectable()
export class DevSeeder implements Seeder {
  constructor(
    private readonly superAdminRepository: SuperAdminRepository,
    private readonly defaultFieldRepository: DefaultFieldRepository,
    private readonly tenantCategoryRepository: TenantCategoryRepository,
    private readonly tenantRepository: TenantRepository,
    private readonly userRepository: UserRepository,
    private readonly roleRepository: RoleRepository,
    private readonly customerRepository: CustomerRepository,
    private readonly employeeRepository: EmployeeRepository,
    private readonly driverRepository: DriverRepository,
    private readonly transportCompanyRepository: TransportCompanyRepository,
    private readonly formTemplateRepository: FormTemplateRepository
  ) {}

  async run(): Promise<void> {
    await appDataSource.transaction(async () => {
      // create superadmin

      await this.superAdminRepository.findOneOrCreate(
        { email: testSuperAdminUser.email },
        {
          ...testSuperAdminUser,
          password: await EncryptHelper.hash(testAdminEmployee.password!),
        }
      )

      // create tenant categories

      const _tenantCategory = await this.tenantCategoryRepository.findOneOrCreate(
        { name: testTenantCategory.name },
        testTenantCategory
      )
      // create default fields
      for (const defaultField of testDefaultFields!) {
        await this.defaultFieldRepository.findOneOrCreate(
          { ...defaultField },
          { ...defaultField, category: _tenantCategory }
        )
      }

      // create tenants

      const _tenant = await this.tenantRepository.findOneOrCreate(
        { rut: testTenant.rut },
        { ...testTenant, category: _tenantCategory! }
      )

      // create roles
      const _adminEmployeeRole = await this.roleRepository.findOneOrCreate(
        { name: adminEmployeeRole.name },
        adminEmployeeRole,
        _tenant.id!
      )
      const _vendorEmployeeRole = await this.roleRepository.findOneOrCreate(
        { name: vendorEmployeeRole.name },
        vendorEmployeeRole,
        _tenant.id!
      )
      const _customerRole = await this.roleRepository.findOneOrCreate(
        { name: customerRole.name },
        customerRole,
        _tenant.id!
      )
      const _driverRole = await this.roleRepository.findOneOrCreate(
        { name: driverRole.name },
        driverRole,
        _tenant.id!
      )

      // create users

      const _userAdminEmployee = await this.userRepository.findOneOrCreate(
        {
          rut: testAdminEmployee.rut,
        },
        {
          ...testAdminEmployee,
          password: await EncryptHelper.hash(testAdminEmployee.password!),
          roles: [_adminEmployeeRole],
        },
        _tenant.id!
      )

      const _userVendorEmployee = await this.userRepository.findOneOrCreate(
        {
          rut: testVendorEmployee.rut,
        },
        {
          ...testVendorEmployee,
          password: await EncryptHelper.hash(testVendorEmployee.password!),
          roles: [_vendorEmployeeRole],
        },
        _tenant.id!
      )

      const _userCustomer = await this.userRepository.findOneOrCreate(
        {
          rut: testCustomer.rut,
        },
        {
          ...testCustomer,
          password: await EncryptHelper.hash(testCustomer.password!),
          roles: [_customerRole],
        },
        _tenant.id!
      )

      const _userDriver = await this.userRepository.findOneOrCreate(
        {
          rut: testDriver.rut,
        },
        {
          ...testDriver,
          password: await EncryptHelper.hash(testDriver.password!),
          roles: [_driverRole],
        },

        _tenant.id!
      )

      // create employees
      const _adminEmployee = await this.employeeRepository.findOneOrCreate(
        {
          user: {
            rut: _userAdminEmployee.rut,
          },
        },
        { ...testAdminEmployee.employee, user: _userAdminEmployee },
        _tenant.id!
      )

      const _vendorEmployee = await this.employeeRepository.findOneOrCreate(
        {
          user: {
            rut: _userVendorEmployee.rut,
          },
        },
        { ...testVendorEmployee.employee, user: _userVendorEmployee },
        _tenant.id!
      )

      // create customer
      const _customer = await this.customerRepository.findOneOrCreate(
        {
          user: {
            rut: _userCustomer.rut,
          },
        },
        { ...testCustomer.customer, user: _userCustomer },
        _tenant.id!
      )
      // create driver
      const _driver = await this.driverRepository.findOneOrCreate(
        {
          user: {
            rut: _userDriver.rut,
          },
        },
        { ..._userDriver.driver, user: _userDriver },
        _tenant.id!
      )

      // create tenant fields

      await this.formTemplateRepository.findOneOrCreate(
        {},
        {
          ...testFormTemplate,
        },
        _tenant.id!
      )

      // create transport company
      const _transportCompany = await this.transportCompanyRepository.findOneOrCreate(
        { rut: testTransportCompany.rut },
        {
          ...testTransportCompany,

          drivers: [_driver],
        },
        _tenant.id!
      )
    })
  }
}
